@@ -15,12 +15,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+from __future__ import annotations
+
 import re
+from typing import Iterator
 
 from click_extra.platform import LINUX
 
-from .. import logger
 from ..base import Package, PackageManager
+from ..capabilities import search_capabilities
 
 
 class Flatpak(PackageManager):
@@ -40,7 +43,7 @@ class Flatpak(PackageManager):
     """
 
     @property
-    def installed(self):
+    def installed(self) -> Iterator[Package]:
         """Fetch installed packages.
 
         .. code-block:: shell-session
@@ -69,14 +72,14 @@ class Flatpak(PackageManager):
             match = regexp.match(package)
             if match:
                 name, package_id, installed_version = match.groups()
-                yield Package(
+                yield self.package(
                     id=package_id,
                     name=name,
                     installed_version=installed_version,
                 )
 
     @property
-    def outdated(self):
+    def outdated(self) -> Iterator[Package]:
         """Fetch outdated packages.
 
         .. code-block:: shell-session
@@ -114,17 +117,18 @@ class Flatpak(PackageManager):
                 )
 
                 installed_version = (
-                    current_version.group("version") if current_version else "unknow"
+                    current_version.group("version") if current_version else None
                 )
 
-                yield Package(
+                yield self.package(
                     id=package_id,
                     name=name,
                     latest_version=latest_version,
                     installed_version=installed_version,
                 )
 
-    def search(self, query, extended, exact):
+    @search_capabilities(extended_support=False, exact_support=False)
+    def search(self, query: str, extended: bool, exact: bool) -> Iterator[Package]:
         """Fetch matching packages.
 
         .. caution::
@@ -136,11 +140,6 @@ class Flatpak(PackageManager):
             ► flatpak search gitg --ostree-verbose
             gitg    GUI for git        org.gnome.gitg  3.32.1  stable  flathub
         """
-        if extended:
-            logger.warning(f"{self.id} does not implement extended search operation.")
-        if exact:
-            logger.warning(f"{self.id} does not implement exact search operation.")
-
         output = self.run_cli("search", query, "--ostree-verbose")
 
         regexp = re.compile(
@@ -163,14 +162,14 @@ class Flatpak(PackageManager):
             branch,
             remotes,
         ) in regexp.findall(output):
-            yield Package(
+            yield self.package(
                 id=package_id,
                 name=package_name,
                 description=description,
                 latest_version=version,
             )
 
-    def install(self, package_id):
+    def install(self, package_id: str) -> str:
         """Install one package.
 
         .. code-block:: shell-session
@@ -179,13 +178,19 @@ class Flatpak(PackageManager):
         """
         return self.run_cli("install", package_id)
 
-    def upgrade_cli(self, package_id=None):
+    def upgrade_all_cli(self) -> tuple[str, ...]:
         """Generates the CLI to upgrade all packages (default) or only the one provided
         as parameter.
 
         .. code-block:: shell-session
 
             ► flatpak update --noninteractive
+        """
+        return self.build_cli("update", "--noninteractive")
+
+    def upgrade_one_cli(self, package_id: str) -> tuple[str, ...]:
+        """Generates the CLI to upgrade all packages (default) or only the one provided
+        as parameter.
 
         .. code-block:: shell-session
 
@@ -193,7 +198,7 @@ class Flatpak(PackageManager):
         """
         return self.build_cli("update", "--noninteractive", package_id)
 
-    def cleanup(self):
+    def cleanup(self) -> None:
         """Removes things we don't need anymore.
 
         See:
